<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Default Extension
 *
 * @package		Default module
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl
 * @copyright 	Copyright (c) 2013 Reinos.nl Internet Media
 */

/**
 * Include the config file
 */
require_once PATH_THIRD.'entry_trash/config.php';
 
class Entry_trash_ext 
{	
	
	public $name			= ENTRY_TRASH_NAME;
	public $description		= ENTRY_TRASH_DESCRIPTION;
	public $version			= ENTRY_TRASH_VERSION;
	public $settings 		= array();
	public $docs_url		= '';
	public $settings_exist	= 'n';
	public $required_by 	= array(ENTRY_TRASH_NAME);
	
	private $EE;
	
	/**
	 * Constructor
	 *
	 * @param 	mixed	Settings array or empty string if none exist.
	 */
	public function __construct($settings = '')
	{
		//get the instance of the EE object
		$this->EE =& get_instance();		
	}

	// ----------------------------------------------------------------------

	/**
	 * delete_entries_start
	 *
	 * This hook is executed when an entry is deleted via the control panel, prior to the entry’s deletion. It can be used to perform additional validation / actions before the entry is deleted, or to take over the deletion process.
	 *
	 * @param 
	 */
	function delete_entries_start()
	{
		//last call? Do nothing!
		if ($this->EE->extensions->end_script === TRUE) return;

		//load the hooks methods library
		$this->EE->load->library(ENTRY_TRASH_MAP.'_actions', null, ENTRY_TRASH_MAP);

		//get the entries that have to be delete
		$entries_delete = $this->EE->input->post('delete');

		//loop over the entry ids
		if(!empty($entries_delete))
		{
			foreach($entries_delete as $entry_id)
			{
				// can we delete the item, is the channel allowd
				if(in_array($this->EE->entry_trash_model->get_channel_id_for_entry_id($entry_id), (array)$this->EE->entry_trash_settings->item('channels')))
				{
					//loop through the native EE tables
					foreach($this->EE->entry_trash->ee_tables as $table)
					{
						//set the fields
						$entry_id_field = key($table);
						$table = $table[$entry_id_field];
						
						//copy data to the database
						$this->EE->entry_trash->add_entry_to_trash($entry_id, $table, $entry_id_field);
					}

					//loop through the Third Party tables
					foreach($this->EE->entry_trash->third_party_tables as $table)
					{
						//set the fields
						$entry_id_field = key($table);
						$table = $table[$entry_id_field];

						//copy data to the database
						$this->EE->entry_trash->add_entry_to_trash($entry_id, $table, $entry_id_field);
					}
				}
			}

			/* -------------------------------------------
			/* 'entry_trash_add_to_trash' hook.
			/*
			/* Calling the hook that preform a delete on all Third Party addons. ( (int)$entry_id, (object)$entry_trash)
			/*
			/*  - Added: 1.0
			*/
			if ($this->EE->extensions->active_hook('entry_trash_add_to_trash') === TRUE)
			{
				$this->EE->extensions->call('entry_trash_add_to_trash', $entry_id, $this->EE->entry_trash);
			} 

			//add Flash data
			$this->EE->session->set_flashdata('message_success', 'Entry moved to the Trash');
		}
	}

	// ----------------------------------------------------------------------

	/**
	 * cp_js_end
	 *
	 * @param 	mixed	Settings array or empty string if none exist.
	 */
	function cp_js_end()
	{
		$js = '';
        return $this->EE->extensions->last_call . $js;
	}

	
	// ----------------------------------------------------------------------
	
	/**
	 * Activate Extension
	 *
	 * This function enters the extension into the exp_extensions table
	 *
	 * @see http://codeigniter.com/user_guide/database/index.html for
	 * more information on the db class.
	 *
	 * @return void
	 */
	public function activate_extension()
	{
		//the module will install the extension if needed
		return true;
	}	
	
	// ----------------------------------------------------------------------

	/**
	 * Disable Extension
	 *
	 * This method removes information from the exp_extensions table
	 *
	 * @return void
	 */
	function disable_extension()
	{
		//the module will disable the extension if needed
		return true;
	}

	// ----------------------------------------------------------------------

	/**
	 * Update Extension
	 *
	 * This function performs any necessary db updates when the extension
	 * page is visited
	 *
	 * @return 	mixed	void on update / false if none
	 */
	function update_extension($current = '')
	{
		//the module will update the extension if needed
		return true;
	}	
	
	// ----------------------------------------------------------------------
}

/* End of file ext.entry_trash.php */
/* Location: /system/expressionengine/third_party/entry_trash/ext.entry_trash.php */