<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Default  helper
 *
 * @package		Module name
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl/add-ons/add-ons
 * @license  	http://reinos.nl/add-ons/commercial-license
 * @copyright 	Copyright (c) 2013 Reinos.nl Internet Media
 */

class Entry_trash_helper
{
	/**
	 * Remove the double slashes
	 */
	public static function remove_double_slashes($str)
    {
        return preg_replace("#(^|[^:])//+#", "\\1/", $str);
    }

	// ----------------------------------------------------------------------

	/**
	 * Check if Submitted String is a Yes value
	 *
	 * If the value is 'y', 'yes', 'true', or 'on', then returns TRUE, otherwise FALSE
	 *
	 */
	public static function check_yes($which, $string = false)
	{
	    if (is_string($which))
	    {
	        $which = strtolower(trim($which));
	    }

	    $result = in_array($which, array('yes', 'y', 'true', 'on'), TRUE);

	    if($string)
	    {
	       return $result ? 'true' : 'false' ; 
	    }

	    return $result;
	}

	// ------------------------------------------------------------------------

	/**
	 * Log an array to a file
	 *
	 */
	public static function log_array($array)
    {
		@file_put_contents(__DIR__.'/print.txt', print_r($array, true));
    }

	// ----------------------------------------------------------------------------------

	/**
	* Log all messages
	*
	* @param array $logs The debug messages.
	* @return void
	*/
	public static function log_to_ee( $logs = array(), $name = '')
    {
        if(!empty($logs))
        {
            foreach ($logs as $log)
            {
                $this->EE->TMPL->log_item('&nbsp;&nbsp;***&nbsp;&nbsp;'.$name.' debug: ' . $log);
            }
        }
    }

	// ------------------------------------------------------------------------

	/**
	 * Is the string serialized
	 *
	 */
	public static function is_serialized($val)
    {
        if (!is_string($val)){ return false; }
        if (trim($val) == "") { return false; }
        if (preg_match("/^(i|s|a|o|d):(.*);/si",$val)) { return true; }
        return false;
    }

	// ------------------------------------------------------------------------

	/**
	 * Is the string json
	 *
	 */
	public static function is_json($string)
    {
       json_decode($string);
        return (json_last_error() == JSON_ERROR_NONE);
    }

	// ------------------------------------------------------------------------

	/**
	 * Retrieve site path
	 */
	public static function get_site_path()
    {
        // extract path info
        $site_url_path = parse_url($this->EE->functions->fetch_site_index(), PHP_URL_PATH);

        $path_parts = pathinfo($site_url_path);
        $site_path = $path_parts['dirname'];

        $site_path = str_replace("\\", "/", $site_path);

        return $site_path;
    }   

	// ------------------------------------------------------------------------

	/**
	 * remove beginning and ending slashes in a url
	 *
	 * @param  $url
	 * @return void
	 */
	public static function remove_begin_end_slash($url, $slash = '/')
    {
        $url = explode($slash, $url);
        array_pop($url);
        array_shift($url);
        return implode($slash, $url);
    }

	// ----------------------------------------------------------------------

	/**
	 * add slashes for an array
	 *
	 * @param  $arr_r
	 * @return void
	 */
	public static function add_slashes_extended(&$arr_r)
    {
        if(is_array($arr_r))
        {
            foreach ($arr_r as &$val)
                is_array($val) ? add_slashes_extended($val):$val=addslashes($val);
            unset($val);
        }
        else
            $arr_r = addslashes($arr_r);
    }

	// ----------------------------------------------------------------

	/**
	 * add a element to a array
	 *
	 * @return  DB object
	 */
	public static function array_unshift_assoc(&$arr, $key, $val)
    {
        $arr = array_reverse($arr, true);
        $arr[$key] = $val;
        $arr = array_reverse($arr, true);
        return $arr;
    }

	// ----------------------------------------------------------------------

	/**
	 * get the memory usage
	 *
	 * @param 
	 * @return void
	 */
	public static function memory_usage()
    {
         $mem_usage = memory_get_usage(true);
       
        if ($mem_usage < 1024)
            return $mem_usage." bytes";
        elseif ($mem_usage < 1048576)
            return round($mem_usage/1024,2)." KB";
        else
            return round($mem_usage/1048576,2)." MB";
    }

	// ----------------------------------------------------------------------

	
	
} // END CLASS

/* End of file entry_trash_helper.php  */
/* Location: ./system/expressionengine/third_party/entry_trash/libraries/entry_trash_helper.php */