<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Default library helper
 *
 * @package		Module name
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl
 * @copyright 	Copyright (c) 2013 Reinos.nl Internet Media
 */

/**
 * Include the config file
 */
require_once PATH_THIRD.'entry_trash/config.php';

/**
 * Include helper
 */
require_once PATH_THIRD.'entry_trash/libraries/entry_trash_helper.php';

class Entry_trash_library
{
	private $default_settings;
	private $settings;
	private $EE;

	//debug array
	public $debug = array();

	public function __construct()
	{							
		// Creat EE Instance
		$this->EE =& get_instance();

		//load model
		$this->EE->load->model(ENTRY_TRASH_MAP.'_model');

		//load the channel data
		//$this->EE->load->driver('channel_data');

		//load settings
		$this->EE->load->library('entry_trash_settings');
		
		//require the default settings
		require PATH_THIRD.ENTRY_TRASH_MAP.'/settings.php';
	}

	// ----------------------------------------------------------------------
	// CUSTOM FUNCTIONS
	// ----------------------------------------------------------------------

	/**
	 * Add an entry (*and associated data) to the trash
	 *
	 * @param none
	 * @return void
	 */
	public function add_entry_to_trash($entry_id = 0, $table = '', $entry_id_field = 'entry_id')
	{
		if($entry_id != 0 && $table != '')
		{
			if ($this->EE->db->table_exists($table))
			{
				//is there a field entry_id in the table?
				//otherwise we cannot select the correct data
				if ($this->EE->db->field_exists($entry_id_field, $table))
				{
					//get the data
					$this->EE->db->where($entry_id_field, $entry_id);
					$this->EE->db->from($table);
					$q = $this->EE->db->get();

					//copy this to the trash DB
					if($q->num_rows() > 0)
					{
						foreach($q->result() as $val)
						{
							$this->EE->entry_trash_model->add_entry_to_trash($entry_id, $table, $entry_id_field, $val);
						}
					}
				}
			}
		}
	}

	// ----------------------------------------------------------------------
	
	/**
	 * This will test an entry if this can be restored
	 *
	 * 
	 *
	 * @todo  validation?! where?! research.
	 * @param none
	 * @return void
	 */
	public function test_restore_entry_from_trash($entry_id = 0)
	{
		//get the item
		$item = $this->EE->entry_trash_model->get_trash($entry_id);

		//error array
		$errors = array();


		//restore the data
		if($item->num_rows() > 0)
		{
			//restore per table
			foreach($item->result() as $val)
			{
				//set the array
				$errors[$val->table]['fields'] = array();
				$errors[$val->table]['table'] = array();

				//table exists
				if ($this->EE->db->table_exists($val->table))
				{
					//get the data
					$data = unserialize($val->data);

					//check if the colomn/fields are exists for this table
					if(!empty($data))
					{
						foreach($data as $key=>$v)
						{
							//check the field
							if(!$this->EE->db->field_exists($key, $val->table))
							{
								$errors[$val->table]['fields'][] = array(
									'field' => $key,
									'message' => 'Field '.$key.' not exists'
								);
							}
						}
					}
				}

				//table is not existsing
				else
				{
					$errors[$val->table]['table'] = array(
						'table' => $val->table,
						'message' => 'Table '.$val->table.' not exists'
					);;
				}
			}
		}

		//return array with the empty array removed
		return $this->_array_remove_empty($errors);
	}

	// ----------------------------------------------------------------------
	
	/**
	 * This will restore an entry form the trash back to the entry table(s)
	 *
	 * (This will also restore other third_party data)
	 *
	 * @todo  validation?! where?! research.
	 * @param none
	 * @return void
	 */
	public function restore_entry_from_trash($entry_id = 0)
	{
		//set basic vars
		$channel_id = 0;
		$new_entry_id = 0;
		$old_entry_id = 0;		

		//get the item
		$item = $this->EE->entry_trash_model->get_trash($entry_id);
		
		//restore the data
		if($item->num_rows() > 0)
		{
			//restore per table
			foreach($item->result() as $val)
			{
				//table exist?!
				if ($this->EE->db->table_exists($val->table))
				{
					//unserialize the data back
					$data = unserialize($val->data);

					//save the old entry_id
					if($val->table == 'channel_titles')
					{
						//save the old one
						$old_entry_id = $data->entry_id;

						//unset the entry_id, we create a new entry_id based on the 'channel_titles' table
						unset($data->entry_id);
					}

					//set the new entry_id var for all tables except the 'channel_titles'
					if($val->table != 'channel_titles')
					{
						$data->{$val->entry_id_field} = $new_entry_id;
					}
					
					//Restore data back
					$this->EE->db->insert($val->table, $data);	

					//get the channel ID
					if($val->table == 'channel_titles')
					{
						$channel_id = $data->channel_id;
						$new_entry_id = $this->EE->db->insert_id();
					}
				}

				// when data can`t be restored, add this to a special table	
				else
				{
					//insert into new tabel
					$this->EE->db->insert(ENTRY_TRASH_MAP.'_items_cant_restored', array(
						'site_id' => $val->site_id,
						'entry_id' => $new_entry_id,
						'table' => $val->table,
						'data' => $val->data
					));
				}			
			}

			/* -------------------------------------------
			/* 'entry_trash_restore_from_trash' hook.
			/*
			/* This hook will call after the restore. 
			/*
			/*  - Added: 1.0
			*/
			if ($this->EE->extensions->active_hook('entry_trash_restore_from_trash') === TRUE)
			{
				$this->EE->extensions->call('entry_trash_restore_from_trash', $new_entry_id, $old_entry_id);
			} 

			//update the channel stats
			$this->EE->stats->update_channel_stats($channel_id);

			//update the comment stats if needed?
			if($this->_comments_installed())
			{
				$this->EE->stats->update_comment_stats($channel_id);
			}
			
			//clear all cache
			$this->EE->functions->clear_caching('all', '', TRUE);

			//delete trash item
			$this->delete_entry_from_trash($entry_id);
		}
	}

	// ----------------------------------------------------------------------
	
	/**
	 * Delete an entry from the trash
	 *
	 * @param none
	 * @return void
	 */
	public function delete_entry_from_trash($entry_id = 0)
	{
		$this->EE->entry_trash_model->delete_entry_from_trash($entry_id);
	}

	// ----------------------------------------------------------------------

	/**
	 * Empty trash (entry by entry)
	 *
	 * @param none
	 * @return void
	 */
	public function truncate_trash($entry_id = '')
	{
		$entries = $this->EE->entry_trash_model->get_all_trash($entry_id);
		$associated_data = $this->get_trash($entry_id);

		//delete only when we need to delete something
		if(!empty($entries))
		{
			foreach($entries as $entry)
			{
				//delete the item
				$this->delete_entry_from_trash($entry->entry_id);

				/* -------------------------------------------
				/* 'entry_trash_delete_from_trash' hook.
				/*
				/* Third_party devs can do extra handlings with this hook. (e.g. channel files need to delete files and images...)
				/*
				/*  - Added: 1.0
				*/
				if ($this->EE->extensions->active_hook('entry_trash_delete_from_trash') === TRUE)
				{
					$this->EE->extensions->call('entry_trash_delete_from_trash', $entry->entry_id, $associated_data);
				} 
			}
		}
	}

	// ----------------------------------------------------------------------

	/**
	 * Empty trash (entry by entry)
	 *
	 * @param none
	 * @return void
	 */
	public function get_trash($entry_id = '')
	{
		$result = $this->EE->entry_trash_model->get_trash($entry_id);

		$data = array();

		if($result->num_rows > 0)
		{
			foreach($result->result() as $key=>$val)
			{
				$data[$val->table][$key] = $val;
				$data[$val->table][$key]->data = unserialize($val->data);

				//reindex the index numbers
				sort($data[$val->table]);
			}
		}

		return $data;

	}

	// ----------------------------------------------------------------------
	// PRIVATE FUNCTIONS
	// ----------------------------------------------------------------------
	
	/**
	 * Delete an entry from the trash
	 *
	 * @param none
	 * @return void
	 */
	private function _comments_installed()
	{
		$this->EE->load->library('addons');
		if (array_key_exists('comment', $this->EE->addons->get_installed('modules')))
		{
			$comments_installed = TRUE;
		}
		else
		{
			$comments_installed = FALSE;
		}

		return $comments_installed;
	}

	// ----------------------------------------------------------------------

	/**
	 * Delete an entry from the trash
	 *
	 * @param none
	 * @return void
	 */
	private function _array_remove_empty($haystack)
	{
		foreach ($haystack as $key => $value) {
			if (is_array($value)) {
				$haystack[$key] = $this->_array_remove_empty($haystack[$key]);
			}

			if (empty($haystack[$key])) {
				unset($haystack[$key]);
			}
		}

		return $haystack;
	}

	// ----------------------------------------------------------------------

	// ----------------------------------------------------------------------
	// DEFAULT FUNCTIONS
	// ----------------------------------------------------------------------
	

		
	/**
	 * Include Theme CSS
	 */
	public function include_theme_css($file)
	{
		$this->EE->cp->add_to_head('<link rel="stylesheet" type="text/css" href="'.$this->EE->entry_trash_settings->item('theme_url').'css/'.$file.'" />');
	}

	// ----------------------------------------------------------------------

	/**
	 * Include Theme JS
	 */
	public function include_theme_js($file)
	{
		$this->EE->cp->add_to_foot('<script type="text/javascript" src="'.$this->EE->entry_trash_settings->item('theme_url').'javascript/'.$file.'"></script>');
	}

	// --------------------------------------------------------------------

	/**
	 * Insert CSS
	 */
	public function insert_css($css)
	{
		$this->EE->cp->add_to_head('<style type="text/css">'.$css.'</style>');
	}

	// ----------------------------------------------------------------------

	/**
	 * Insert JS
	 */
	public function insert_js($js)
	{
		$this->EE->cp->add_to_foot('<script type="text/javascript">'.$js.'</script>');
	}
	
	// ----------------------------------------------------------------------
		
	/**
	 * 	Fetch Action IDs
	 *
	 * 	@access public
	 *	@param string
	 * 	@param string
	 *	@return mixed
	 */
	public function fetch_action_id($class = '', $method)
	{
		$this->EE->db->select('action_id');
		$this->EE->db->where('class', $class);
		$this->EE->db->where('method', $method);
		$query = $this->EE->db->get('actions');
		
		if ($query->num_rows() == 0)
		{
			return FALSE;
		}
		
		return $query->row('action_id');
	}

	// ----------------------------------------------------------------------

	/**
	 * Log all messages
	 *
	 * @param array $logs The debug messages.
	 * @return void
	 */
	public function expose_log()
	{
		if(!empty($this->debug))
		{
			foreach ($this->debug as $log)
			{
				$this->EE->TMPL->log_item('&nbsp;&nbsp;***&nbsp;&nbsp;'.ENTRY_TRASH_CLASS.' debug: ' . $log);
			}
		}
	} 
		
	// ----------------------------------------------------------------------
	 
	
	
} // END CLASS

/* End of file entry_trash_library.php  */
/* Location: ./system/expressionengine/third_party/entry_trash/libraries/entry_trash_library.php */