<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Default Module Control Panel File
 *
 * @package		Default module
 * @category	Modules
 * @author		Rein de Vries <info@reinos.nl>
 * @link		http://reinos.nl
 * @copyright 	Copyright (c) 2013 Reinos.nl Internet Media
 */

/**
 * Include the config file
 */
require_once PATH_THIRD.'entry_trash/config.php';

class Entry_trash_mcp {
	
	public $return_data;
	public $settings;
	
	private $show_per_page = 25;
	private $_base_url;

	/**
	 * Constructor
	 */
	public function __construct()
	{
		$this->EE =& get_instance();
		
		//load the library`s
		$this->EE->load->library('table');
		$this->EE->load->library(ENTRY_TRASH_MAP.'_library');
		$this->EE->load->model(ENTRY_TRASH_MAP.'_model');
		$this->EE->load->helper('form');	
		$this->EE->load->library('javascript');
		$this->EE->load->library('pagination');
	   
	   //set the right nav
		$right_nav = array();
		$right_nav[lang(ENTRY_TRASH_MAP.'_overview')] = $this->EE->entry_trash_settings->item('base_url');
		$right_nav[lang(ENTRY_TRASH_MAP.'_settings')] = $this->EE->entry_trash_settings->item('base_url').AMP.'method=settings';
		$right_nav[lang(ENTRY_TRASH_MAP.'_empty_trash')] = $this->EE->entry_trash_settings->item('base_url').AMP.'method=empty_trash';
		$this->EE->cp->set_right_nav($right_nav);

		//load dialog
		$this->EE->cp->add_js_script(array('ui' => 'dialog'));
		//add css
		$this->EE->entry_trash_library->include_theme_css('font-awesome.min.css');
		$this->EE->entry_trash_library->include_theme_css('entry_trash.css');
		
		//require the default settings
		require PATH_THIRD.ENTRY_TRASH_MAP.'/settings.php';
	}
	
	// ----------------------------------------------------------------

	/**
	 * Index Function
	 *
	 * @return 	void
	 */
	public function index()
	{
		// Set Breadcrumb and Page Title
		$this->EE->cp->set_variable('cp_page_title', lang(ENTRY_TRASH_MAP.'_module_name'));
		$vars['cp_page_title'] = lang(ENTRY_TRASH_MAP.'_module_name');

		//set the default arrays
		//$vars['data'] = 'test_data';

		//load the view
		return $this->overview();
		//return $this->EE->load->view('overview', $vars, TRUE);   
	}

	// ----------------------------------------------------------------

	/**
	 * Overview Function
	 *
	 * @return 	void
	 */
	public function overview()
	{
		$vars['base_url_js'] = $this->EE->entry_trash_settings->item('base_url_js');
		$vars['theme_url'] = $this->EE->entry_trash_settings->item('theme_url');

		//load the view
		return $this->EE->load->view('overview', $vars, TRUE);  
	}

	// ----------------------------------------------------------------

	/**
	 * This method will be called by the table class to get the results
	 *
	 * @return 	void
	 */
	public function _datasource($state)
	{
		$offset = $state['offset'];
		$order = $state['sort'];

		$data = $this->EE->entry_trash_model->get_all_trash('', $this->show_per_page, $offset, $order);

		$rows = array();

		if(!empty($data))
		{
			foreach($data as $key=>$val)
			{
				$rows[] = array(
					ENTRY_TRASH_MAP.'_title' => $val->title,
					ENTRY_TRASH_MAP.'_channel' => $val->channel_data->channel_title,
					'actions' => '
					<a class="icon restore_trash_item" data-entryid="'.$val->entry_id.'" data-title="'.$val->title.'"  href="#" >
						<i title="Restore entry" class="icon-undo "></i>
					</a>
					<a class="icon" data-entryid="'.$val->entry_id.'" href="'.$this->EE->entry_trash_settings->item('base_url_js').'&method=delete_trash_item'.AMP.'entry_id='.$val->entry_id.'">
						<i title="Delete entry" class="icon-trash "></i>
					</a>
					<a href="#" data-entryid="'.$val->entry_id.'" class="icon show_trash_item">
						<i title="Show entry" class="icon-external-link "></i>
					</a>
					'
				);
			}
		}
		//empty
		else
		{
			$rows[] = array(
				ENTRY_TRASH_MAP.'_title' => '',
				ENTRY_TRASH_MAP.'_channel' => '',
				'actions' => ''
			);
		}

		//return the data
		return array(
			'rows' => $rows,
			'pagination' => array(
				'per_page'   => $this->show_per_page,
				'total_rows' => $this->EE->entry_trash_model->count_trash(),
			),
		);
	}

	// ----------------------------------------------------------------

	/**
	 * Overview Function
	 *
	 * @return 	void
	 */
	public function show_trash_item()
	{
		//paging
		$entry_id = $this->EE->input->get('entry_id');
		
		//get the data 
		$vars['data'] = $this->EE->entry_trash_model->get_trash($entry_id);

		//empty vars 
		//$vars['search_alias'] = '';

		//load the view
		echo $this->EE->load->view('show_trash_item', $vars, TRUE);  
		exit;
	}

	// ----------------------------------------------------------------

	/**
	 * Overview Function
	 *
	 * @return 	void
	 */
	public function restore_trash_item()
	{
		//load the hooks methods library
		$this->EE->load->library(ENTRY_TRASH_MAP.'_actions', null, ENTRY_TRASH_MAP);

		//get the entry id
		$entry_id = $this->EE->input->get_post('entry_id');

		//restore the entry
		//this method will also restore other tables e.g. third_party
		$this->EE->entry_trash->restore_entry_from_trash($entry_id);
		
		//set a message
		$this->EE->session->set_flashdata(
			'message_success',
			$this->EE->lang->line(ENTRY_TRASH_MAP.'_restored')
		);
		
		//redirect
		$this->EE->functions->redirect(BASE.AMP.'C=addons_modules'.AMP.'M=show_module_cp'.AMP.'module='.ENTRY_TRASH_MAP);		
	}

	// ----------------------------------------------------------------

	/**
	 * Test a entry if this can be resotred
	 * is ajax call
	 *
	 * @return 	void
	 */
	public function test_restore_trash_item()
	{
		//load the hooks methods library
		$this->EE->load->library(ENTRY_TRASH_MAP.'_actions', null, ENTRY_TRASH_MAP);

		//get the entry id
		$entry_id = $this->EE->input->get_post('entry_id');

		//test the entry
		$tests = $this->EE->entry_trash->test_restore_entry_from_trash($entry_id);
		$tests = !empty($tests) ? $tests : '';
		//return json string
		echo json_encode($tests);
		exit;	
	}

	// ----------------------------------------------------------------

	/**
	 * Empty the whole trash
	 *
	 * @return 	void
	 */
	public function empty_trash()
	{
		// Set Breadcrumb and Page Title
		$this->EE->cp->set_variable('cp_page_title', lang(ENTRY_TRASH_MAP.'_module_name'));
		$vars['cp_page_title'] = lang(ENTRY_TRASH_MAP.'_module_name');

		//confirm for empty trash
		if($this->EE->input->post('confirm') == 'ok')
		{
			//empty trash table
			$this->EE->entry_trash_library->truncate_trash();
			
			//set a message
			$this->EE->session->set_flashdata(
				'message_success',
				$this->EE->lang->line(ENTRY_TRASH_MAP.'_empty_trashed')
			);
			
			//redirect
			$this->EE->functions->redirect(BASE.AMP.'C=addons_modules'.AMP.'M=show_module_cp'.AMP.'module='.ENTRY_TRASH_MAP);	
		}

		$var = array();
		$var['method'] = 'empty_trash';
		$var['entry_id'] = '';
		$var['message'] = lang(ENTRY_TRASH_MAP.'_empty_trash_delete_confirm');

		return $this->EE->load->view('delete', $var, TRUE);
	}

	/**
	 * Delete one trash item
	 *
	 * @return 	void
	 */
	public function delete_trash_item()
	{
		// Set Breadcrumb and Page Title
		$this->EE->cp->set_variable('cp_page_title', lang(ENTRY_TRASH_MAP.'_module_name'));
		$vars['cp_page_title'] = lang(ENTRY_TRASH_MAP.'_module_name');

		//confirm for empty trash
		if($this->EE->input->post('confirm') == 'ok' && $this->EE->input->post('entry_id') != '')
		{
			//delete one trash item
			$this->EE->entry_trash_library->truncate_trash($this->EE->input->post('entry_id'));
			
			//set a message
			$this->EE->session->set_flashdata(
				'message_success',
				$this->EE->lang->line(ENTRY_TRASH_MAP.'_empty_one_trashed')
			);
			
			//redirect
			$this->EE->functions->redirect(BASE.AMP.'C=addons_modules'.AMP.'M=show_module_cp'.AMP.'module='.ENTRY_TRASH_MAP);	
		}

		$var = array();
		$var['method'] = 'delete_trash_item';
		$var['entry_id'] = $this->EE->input->get('entry_id');
		$var['message'] = lang(ENTRY_TRASH_MAP.'_delete_trash_item_delete_confirm');

		return $this->EE->load->view('delete', $var, TRUE);
	}

	/**
	 * Delete one trash item (JS method way)
	 *
	 * @return 	void
	 */
	public function fast_delete_trash_item()
	{
		if($this->EE->input->post('entry_id') != '')
		{
			//delete one trash item
			$this->EE->entry_trash_library->truncate_trash($this->EE->input->post('entry_id'));
			
			//set a message
			$this->EE->session->set_flashdata(
				'message_success',
				$this->EE->lang->line(ENTRY_TRASH_MAP.'_empty_trashed')
			);
		}
		else
		{
			//set a message
			$this->EE->session->set_flashdata(
				'message_success',
				$this->EE->lang->line(ENTRY_TRASH_MAP.'_cannot_empty_trashed')
			);
		}
		
		
		//redirect
		$this->EE->functions->redirect(BASE.AMP.'C=addons_modules'.AMP.'M=show_module_cp'.AMP.'module='.ENTRY_TRASH_MAP);	
	}
	
	// ----------------------------------------------------------------

	/**
	 * Settings Function
	 *
	 * @return 	void
	 */
	public function settings()
	{
		//is there some data tot save?
		if($this->EE->input->post('submit') != '')
		{
			$this->EE->entry_trash_settings->save_post_settings();
		}
				
		// Set Breadcrumb and Page Title
		$this->EE->cp->set_breadcrumb($this->EE->entry_trash_settings->item('base_url'), lang(ENTRY_TRASH_MAP.'_module_name'));
		$this->EE->cp->set_variable('cp_page_title', lang(ENTRY_TRASH_MAP.'_settings'));
		$vars['cp_page_title'] = lang(ENTRY_TRASH_MAP.'_settings');

		//default var array
		$vars = array();
		
		//license key
		$license_key = $this->EE->entry_trash_settings->item('license_key');

		$channels = $this->EE->entry_trash_model->get_channels();
		$channel = $this->EE->entry_trash_settings->item('channels');

		//vars for the view and the form
		$vars['settings']['default'] = array(
			ENTRY_TRASH_MAP.'_license_key'   => form_input('license_key', $license_key),	
			//'debug'   => 'Yes '.form_radio('debug', 1, $debug_yes).' No '.form_radio('debug', 0, $debug_no),	
			'channls' => form_multiselect( 'channels[]', $channels, $channel),
		);

		//load the view
		return $this->EE->load->view('settings', $vars, TRUE);   
	}
	
	// ----------------------------------------------------------------

	/**
	 * Paging
	 *
	 * @return 	void
	 */
	private function _pagination_config($method, $total_rows, $per_page = 25)
	{
		// Pass the relevant data to the paginate class
		$config['base_url'] = BASE.AMP.'C=addons_modules'.AMP.'M=show_module_cp'.AMP.'module='.ENTRY_TRASH_MAP.AMP.'method='.$method;
		$config['total_rows'] = $total_rows;
		$config['per_page'] = $per_page;
		$config['page_query_string'] = TRUE;
		$config['query_string_segment'] = 'row_num';
		$config['full_tag_open'] = '<p id="paginationLinks">';
		$config['full_tag_close'] = '</p>';
		$config['prev_link'] = '<img src="'.$this->EE->cp->cp_theme_url.'images/pagination_prev_button.gif" width="13" height="13" alt="<" />';
		$config['next_link'] = '<img src="'.$this->EE->cp->cp_theme_url.'images/pagination_next_button.gif" width="13" height="13" alt=">" />';
		$config['first_link'] = '<img src="'.$this->EE->cp->cp_theme_url.'images/pagination_first_button.gif" width="13" height="13" alt="< <" />';
		$config['last_link'] = '<img src="'.$this->EE->cp->cp_theme_url.'images/pagination_last_button.gif" width="13" height="13" alt="> >" />';

		return $config;
	}

	// ----------------------------------------------------------------
}
/* End of file mcp.default.php */
/* Location: /system/expressionengine/third_party/default/mcp.default.php */